body {
    font-family: monospace;
}

dd {
    margin: 0;
}

h1 {
    margin: 1em;
}

label {
    margin-left: 1em;
}

pre {
    white-space:pre-wrap;
}

#content {
    background-color: #eee;
    border-style: dotted;
    border-width: 1px;
    margin: 3em;
}

#navigation {
    margin-top: 3em;
}

#navigation li {
    display: inline;
    margin-right: 2em;
}

#navigation li a {
    text-decoration: none;
}

#navigation li.active {
    font-weight: bold;
}

#text {
    height: 20em;
    margin-left: 5em;
    width: 20em;
}

#solution {
    background-color: #ccc;
    border-style: dotted;
    border-width: 1px;
    margin: 3em;
    padding: 1em;
    font-size: .8em
}

#submit_button {
    margin: 1em;
}

.description {
    margin: 1em;
}

.logo {
    margin: 1em 1em 0 5em;
}

.message {
    list-style: none;
}