{% extends "base.html" %}

{% block title %}Parser Exercise{% endblock %}
{% block content %}
    <h1>Ergebnisse - Thomas Rega</h1>
    <img class="logo" src="{{ url_for('static', filename='img/ninja.png') }}" />
{% endblock %}
